@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* conffile.h - the opkg package management system
 
    Carl D. Worth
@@ -19,13 +20,19 @@
 #define CONFFILE_H
 
 #include "nv_pair.h"
-typedef struct nv_pair conffile_t;
-
-#include "opkg_conf.h"
-
-int conffile_init(conffile_t *conffile, const char *file_name, const char *md5sum);
-void conffile_deinit(conffile_t *conffile);
-int conffile_has_been_modified(struct opkg_conf *conf, conffile_t *conffile);
 
+#ifdef __cplusplus
+extern "C" {
 #endif
 
+typedef struct nv_pair conffile_t;
+
+int conffile_init(conffile_t * conffile, const char *file_name,
+                  const char *md5sum);
+void conffile_deinit(conffile_t * conffile);
+int conffile_has_been_modified(conffile_t * conffile);
+
+#ifdef __cplusplus
+}
+#endif
+#endif                          /* CONFFILE_H */
