@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* conffile_list.c - the opkg package management system
 
    Carl D. Worth
@@ -15,34 +16,33 @@
    General Public License for more details.
 */
 
-#include "includes.h"
+#include "config.h"
 
 #include "conffile_list.h"
 
-void conffile_list_init(conffile_list_t *list)
+void conffile_list_init(conffile_list_t * list)
 {
     nv_pair_list_init(list);
 }
 
-void conffile_list_deinit(conffile_list_t *list)
+void conffile_list_deinit(conffile_list_t * list)
 {
     nv_pair_list_deinit(list);
 }
 
-conffile_t *conffile_list_append(conffile_list_t *list, const char *file_name,
-			 const char *md5sum)
+conffile_t *conffile_list_append(conffile_list_t * list, const char *file_name,
+                                 const char *md5sum)
 {
     return nv_pair_list_append(list, file_name, md5sum);
 }
 
-void conffile_list_push(conffile_list_t *list, conffile_t *data)
+void conffile_list_push(conffile_list_t * list, conffile_t * data)
 {
     nv_pair_list_push(list, data);
 }
 
-conffile_list_elt_t *conffile_list_pop(conffile_list_t *list)
+conffile_list_elt_t *conffile_list_pop(conffile_list_t * list)
 {
     conffile_list_elt_t *pos = nv_pair_list_pop(list);
     return pos;
 }
-
