@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* nv_pair.c - the opkg package management system
 
    Carl D. Worth
@@ -15,10 +16,14 @@
    General Public License for more details.
 */
 
-#include "nv_pair.h"
-#include "libbb/libbb.h"
+#include "config.h"
 
-int nv_pair_init(nv_pair_t *nv_pair, const char *name, const char *value)
+#include <malloc.h>
+
+#include "nv_pair.h"
+#include "xfuncs.h"
+
+int nv_pair_init(nv_pair_t * nv_pair, const char *name, const char *value)
 {
 
     nv_pair->name = xstrdup(name);
@@ -27,7 +32,7 @@ int nv_pair_init(nv_pair_t *nv_pair, const char *name, const char *value)
     return 0;
 }
 
-void nv_pair_deinit(nv_pair_t *nv_pair)
+void nv_pair_deinit(nv_pair_t * nv_pair)
 {
     free(nv_pair->name);
     nv_pair->name = NULL;
@@ -35,5 +40,3 @@ void nv_pair_deinit(nv_pair_t *nv_pair)
     free(nv_pair->value);
     nv_pair->value = NULL;
 }
-
-
