@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* opkg_install.h - the opkg package management system
 
    Carl D. Worth
@@ -25,12 +26,14 @@
 extern "C" {
 #endif
 
+int opkg_install_pkg(pkg_t * pkg, int from_upgrading);
+
+#ifndef HAVE_SOLVER
 int opkg_install_by_name(const char *pkg_name);
-int opkg_install_multiple_by_name(str_list_t *pkg_names);
-int opkg_install_pkg(pkg_t *pkg, int from_upgrading);
+int opkg_install_multiple_by_name(str_list_t * pkg_names);
+#endif
 
 #ifdef __cplusplus
 }
 #endif
-
-#endif /* OPKG_INSTALL_H */
+#endif                          /* OPKG_INSTALL_H */
