@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* opkg_remove.h - the opkg package management system
 
    Carl D. Worth
@@ -21,10 +22,20 @@
 #include "pkg.h"
 #include "opkg_conf.h"
 
-int opkg_remove_pkg(opkg_conf_t *conf, pkg_t *pkg,int message);
-int pkg_has_installed_dependents(opkg_conf_t *conf, abstract_pkg_t *parent_apkg, pkg_t *pkg, abstract_pkg_t *** pdependents);
-void remove_data_files_and_list(opkg_conf_t *conf, pkg_t *pkg);
-void remove_maintainer_scripts(opkg_conf_t *conf, pkg_t *pkg);
-
-
+#ifdef __cplusplus
+extern "C" {
 #endif
+
+int opkg_remove_pkg(pkg_t * pkg);
+void remove_data_files_and_list(pkg_t * pkg);
+void remove_maintainer_scripts(pkg_t * pkg);
+
+#ifndef HAVE_SOLVER
+int pkg_has_installed_dependents(pkg_t * pkg,
+                                 abstract_pkg_t *** pdependents);
+#endif
+
+#ifdef __cplusplus
+}
+#endif
+#endif                          /* OPKG_REMOVE_H */
