@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* opkg_upgrade.c - the opkg package management system
 
    Copyright (C) 2003 Daniele Nicolodi <daniele@grinta.net>
@@ -16,7 +17,18 @@
 #define OPKG_UPGRADE_H
 
 #include "active_list.h"
-int opkg_upgrade_pkg(pkg_t *old);
-struct active_list * prepare_upgrade_list (void);
+#include "pkg.h"
+#include "pkg_vec.h"
 
+#ifdef __cplusplus
+extern "C" {
 #endif
+
+int opkg_upgrade_pkg(pkg_t * old);
+int opkg_upgrade_multiple_pkgs(pkg_vec_t * pkgs_to_upgrade);
+struct active_list *prepare_upgrade_list(void);
+
+#ifdef __cplusplus
+}
+#endif
+#endif                          /* OPKG_UPGRADE_H */
