@@ -1,7 +1,8 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* opkg_utils.h - the opkg package management system
 
    Steven M. Ayer
-   
+
    Copyright (C) 2002 Compaq Computer Corporation
 
    This program is free software; you can redistribute it and/or
@@ -18,15 +19,16 @@
 #ifndef OPKG_UTILS_H
 #define OPKG_UTILS_H
 
-#include "pkg.h"
-#include "opkg_error.h"
+#ifdef __cplusplus
+extern "C" {
+#endif
 
-void push_error_list(char * msg);
-void free_error_list(void);
-void print_error_list(void);
-
-long unsigned int get_available_blocks(char * filesystem);
+unsigned long get_available_kbytes(char *filesystem);
 char *trim_xstrdup(const char *line);
 int line_is_blank(const char *line);
+int str_starts_with(const char *str, const char *prefix);
 
+#ifdef __cplusplus
+}
 #endif
+#endif                          /* OPKG_UTILS_H */
