@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* pkg_src.h - the opkg package management system
 
    Carl D. Worth
@@ -20,15 +21,27 @@
 
 #include "nv_pair.h"
 
-typedef struct 
-{
-  char *name;
-  char *value;
-  char *extra_data;
-  int gzip;
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+typedef struct {
+    char *name;
+    char *value;
+    char *extra_data;
+    int gzip;
 } pkg_src_t;
 
-int pkg_src_init(pkg_src_t *src, const char *name, const char *base_url, const char *extra_data, int gzip);
-void pkg_src_deinit(pkg_src_t *src);
+int pkg_src_init(pkg_src_t * src, const char *name, const char *base_url,
+                 const char *extra_data, int gzip);
+void pkg_src_deinit(pkg_src_t * src);
 
+int pkg_src_download(pkg_src_t * src);
+int pkg_src_download_signature(pkg_src_t * src);
+int pkg_src_verify(pkg_src_t * src);
+int pkg_src_update(pkg_src_t * src);
+
+#ifdef __cplusplus
+}
 #endif
+#endif                          /* PKG_SRC_H */
