@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* xsystem.c - system(3) with error messages
 
    Carl D. Worth
@@ -21,8 +22,8 @@
 #include <sys/wait.h>
 #include <unistd.h>
 
+#include "opkg_message.h"
 #include "xsystem.h"
-#include "libbb/libbb.h"
 
 /* Like system(3), but with error messages printed if the fork fails
    or if the child process dies due to an uncaught signal. Also, the
@@ -32,44 +33,46 @@
    Otherwise, the 8-bit return value of the program ala WEXITSTATUS
    as defined in <sys/wait.h>.
 */
-int
-xsystem(const char *argv[])
+int xsystem(const char *argv[])
 {
-	int status;
-	pid_t pid;
+    int status;
+    pid_t pid;
+    int r;
 
-	pid = vfork();
+    pid = vfork();
 
-	switch (pid) {
-	case -1:
-		opkg_perror(ERROR, "%s: vfork", argv[0]);
-		return -1;
-	case 0:
-		/* child */
-		execvp(argv[0], (char*const*)argv);
-		_exit(-1);
-	default:
-		/* parent */
-		break;
-	}
+    switch (pid) {
+    case -1:
+        opkg_perror(ERROR, "%s: vfork", argv[0]);
+        return -1;
+    case 0:
+        /* child */
+        execvp(argv[0], (char *const *)argv);
+        _exit(-1);
+    default:
+        /* parent */
+        break;
+    }
 
-	if (waitpid(pid, &status, 0) == -1) {
-		opkg_perror(ERROR, "%s: waitpid", argv[0]);
-		return -1;
-	}
+    r = waitpid(pid, &status, 0);
+    if (r == -1) {
+        opkg_perror(ERROR, "%s: waitpid", argv[0]);
+        return -1;
+    }
 
-	if (WIFSIGNALED(status)) {
-		opkg_msg(ERROR, "%s: Child killed by signal %d.\n",
-			argv[0], WTERMSIG(status));
-		return -1;
-	}
+    if (WIFSIGNALED(status)) {
+        opkg_msg(ERROR, "%s: Child killed by signal %d.\n", argv[0],
+                 WTERMSIG(status));
+        return -1;
+    }
 
-	if (!WIFEXITED(status)) {
-		/* shouldn't happen */
-		opkg_msg(ERROR, "%s: Your system is broken: got status %d "
-			"from waitpid.\n", argv[0], status);
-		return -1;
-	}
+    if (!WIFEXITED(status)) {
+        /* shouldn't happen */
+        opkg_msg(ERROR,
+                 "%s: Your system is broken: got status %d " "from waitpid.\n",
+                 argv[0], status);
+        return -1;
+    }
 
-	return WEXITSTATUS(status);
+    return WEXITSTATUS(status);
 }
