@@ -57,6 +57,8 @@ enum {
     ARGS_OPT_VOLATILE_CACHE,
     ARGS_OPT_COMBINE,
     ARGS_OPT_NO_INSTALL_RECOMMENDS,
+    ARGS_OPT_CACHE_DIR,
+    ARGS_OPT_HOST_CACHE_DIR,
 };
 
 static struct option long_options[] = {
@@ -107,6 +109,8 @@ static struct option long_options[] = {
     {"test", 0, 0, ARGS_OPT_NOACTION},
     {"tmp-dir", 1, 0, 't'},
     {"tmp_dir", 1, 0, 't'},
+    {"cache-dir", 1, 0, ARGS_OPT_CACHE_DIR},
+    {"host-cache-dir", 0, 0, ARGS_OPT_HOST_CACHE_DIR},
     {"volatile-cache", 0, 0, ARGS_OPT_VOLATILE_CACHE},
     {"verbosity", 2, 0, 'V'},
     {"version", 0, 0, 'v'},
@@ -213,6 +217,12 @@ static int args_parse(int argc, char *argv[])
         case ARGS_OPT_DOWNLOAD_ONLY:
             opkg_config->download_only = 1;
             break;
+        case ARGS_OPT_CACHE_DIR:
+            opkg_config->cache_dir = xstrdup(optarg);
+            break;
+        case ARGS_OPT_HOST_CACHE_DIR:
+            opkg_config->host_cache_dir = 1;
+            break;
         case ARGS_OPT_VOLATILE_CACHE:
             opkg_config->volatile_cache = 1;
             break;
@@ -322,6 +332,8 @@ static void usage()
     printf("\t                                automatically to satisfy dependencies\n");
     printf("\t-t                              Specify tmp-dir.\n");
     printf("\t--tmp-dir                       Specify tmp-dir.\n");
+    printf("\t--cache-dir <path>              Specify cache directory.\n");
+    printf("\t--host-cache-dir                Don't place cache in offline root dir.\n");
     printf("\t--volatile-cache                Use volatile cache.\n");
     printf("\t                                Volatile cache will be cleared on exit\n");
 
